FermiLib plugin to interface with Psi4
======================================

This repository contains a plugin which allows `FermiLib <http://github.com/ProjectQ-Framework/FermiLib>`__ (licensed under Apache 2) to interface with the open-source quantum chemistry package `Psi4 <http://www.psicode.org>`__ (licensed under GNU Lesser General Public License version 3). 

License
-------
Copyright (C) 2017 FermiLib Developers

This plugin is released under the GNU Lesser General Public License (LGPL), Version 3 or any later version.
